@@ -10,7 +10,6 @@ from .usage import usage
 
 
 def get_target(name=None, dest=None):
-    name = name or environ.get('setux_target')
     if not dest:
         dest = environ.get('setux_outdir')
         if dest:
@@ -18,11 +17,13 @@ def get_target(name=None, dest=None):
             dest = f'{dest}/{user}'
         else:
             dest = expanduser('~/setux')
-    if name:
+
+    name = name or environ.get('setux_target')
+    try:
         target = SSH(name=name, host=name, outdir=dest)
-        if not target.cnx:
-            target = None
-    else:
+    except Exception:
+        target = None
+    if not target or not target.cnx:
         target = Local(outdir=dest)
     return target
 
@@ -39,7 +40,8 @@ def main():
         except: target = None
 
         if target:
-            del argv[-1]
+            if argv[-1]==target.name:
+                del argv[-1]
         else:
             target = get_target()
 
