@@ -183,6 +183,14 @@ def outlog(target, arg):
     else:
         print('target outlog not defined')
 
+def send(target, local, remote=None):
+    ok = target.send(
+        local,
+        remote or local,
+    )
+    status = '.' if ok else 'X'
+    return ok
+
 def edit(target, remote):
     editor = environ.get('EDITOR','vim')
     dest = Path('/tmp/setux')
